* Commodity Currencies and Monetary Policy
* Michael B. Devereux and Gregor W. Smith
* October 2020
*
*
calendar 1985 1 12
allocate 2020:7
*
open data CanadaData2020.txt
data(org=obs,missing=-99) 1985:1 2020:7 x s d xm
*
* These are in levels:
* Convert to logs:
set x = log(x)
set s = log(s)
set xm = log(xm)
* Create growth rates:
set dd = d-d(t-1)
set dx = x-x(t-1)
set dxm = xm-xm(t-1)
set ds = s-s(t-1)
*
************************************
* 1. System FMOLS:
@fm(lags=3)
# d x
compute bot=%beta(2)
compute botse=%stderrs(2)
display bot
@fm(lags=3)
# s x
* The ratio of these two gives the estimate of alpha.
* Construct its standard error by the delta method:
compute top=%beta(2)
compute topse=%stderrs(2)
*
compute a=top/bot
compute sea = ((topse/bot)**2 + (botse)**2*top**2/(bot**4))**(0.5)
display 'Estimate of alpha' a
display 'Standard error of alpha:' sea
*
*
***
* Same thing for the energy component:
*
@fm(lags=3)
# d xm
compute bot=%beta(2)
compute botse=%stderrs(2)
display bot
@fm(lags=3)
# s xm
* The ratio of these two gives the estimate of alpha.
* Construct its standard error by the delta method:
compute top=%beta(2)
compute topse=%stderrs(2)
*
compute a=top/bot
compute sea = ((topse/bot)**2 + (botse)**2*top**2/(bot**4))**(0.5)
display 'Estimate of alpha' a
display 'Standard error of alpha:' sea
*
*************************************
*
* 2. GMM step on stationary variables:
*
* Use the value of alpha from FM, to create y:
compute a = 0.245
set y = s-a*d
*
*
*****************************************
* Campbell-Shiller transformation, IV version:
* Estimation by continuously-updated GMM with Newey-West standard errors.
*
* (a) just-identified
nonlin b c
compute c=0
compute b=0.95
frml h = y-c-a*b*dd{-1}-b*y{-1}
*
instruments constant dx
nlls(inst,frml=h,optimalweights,robusterrors,lags=2.0,damp=1.0) * 1985:1 2020:7
*

* (b) four lags
nonlin b c
compute c=0
compute b=0.95
frml h = y-c-a*b*dd{-1}-b*y{-1}
*
instruments constant dx{0 to 4}
nlls(inst,frml=h,optimalweights,robusterrors,lags=2.0,damp=1.0) * 1985:1 2020:7
*
*(c) eight lags:
nonlin b c
compute c=0
compute b=0.95
frml h = y-c-a*b*dd{-1}-b*y{-1}
*
instruments constant dx{0 to 8}
nlls(inst,frml=h,optimalweights,robusterrors,lags=2.0,damp=1.0) * 1985:1 2020:7
*
*(d) Twelve lags:
nonlin b c
compute c=0
compute b=0.95
frml h = y-c-a*b*dd{-1}-b*y{-1}
*
instruments constant dx{0 to 12}
nlls(inst,frml=h,optimalweights,robusterrors,lags=2.0,damp=1.0) * 1985:1 2020:7

*************************************
* Repeat for the energy component
* Use the value of alpha from FM, to create y:
compute a = 0.456
set y = s-a*d
*
*
*****************************************
* Campbell-Shiller transformation, IV version:
* Estimation by continuously-updated GMM with Newey-West standard errors.
*
* (a) just identified
nonlin b c
compute c=0
compute b=0.95
frml h = y-c-a*b*dd{-1}-b*y{-1}
*
instruments constant dxm
nlls(inst,frml=h,optimalweights,robusterrors,lags=2.0,damp=1.0) * 1985:1 2020:7
*
*(b) 4 lags:
nonlin b c
compute c=0
compute b=0.95
frml h = y-c-a*b*dd{-1}-b*y{-1}
*
instruments constant dxm{0 to 4}
nlls(inst,frml=h,optimalweights,robusterrors,lags=2.0,damp=1.0) * 1985:1 2020:7

*(c) 8 lags
nonlin b c
compute c=0
compute b=0.95
frml h = y-c-a*b*dd{-1}-b*y{-1}
*
instruments constant dxm{0 to 8}
nlls(inst,frml=h,optimalweights,robusterrors,lags=2.0,damp=1.0) * 1985:1 2020:7

*(d) Twelve lags:
nonlin b c
compute c=0
compute b=0.95
frml h = y-c-a*b*dd{-1}-b*y{-1}
*
instruments constant dxm{0 to 12}
nlls(inst,frml=h,optimalweights,robusterrors,lags=2.0,damp=1.0) * 1985:1 2020:7

